



/* --- gsldatacache.h --- */
#define BSE_TYPE_DATA_CACHE_REQUEST	    (BSE_TYPE_ID (GslDataCacheRequest))
extern GType BSE_TYPE_ID (GslDataCacheRequest);

/* --- gslvorbis-cutter.h --- */
#define BSE_TYPE_VORBIS_CUTTER_MODE	    (BSE_TYPE_ID (GslVorbisCutterMode))
extern GType BSE_TYPE_ID (GslVorbisCutterMode);

/* --- bseexports.h --- */
#define BSE_TYPE_EXPORT_NODE_TYPE	    (BSE_TYPE_ID (BseExportNodeType))
extern GType BSE_TYPE_ID (BseExportNodeType);

/* --- bsebiquadfilter.h --- */
#define BSE_TYPE_BIQUAD_FILTER_TYPE	    (BSE_TYPE_ID (BseBiquadFilterType))
extern GType BSE_TYPE_ID (BseBiquadFilterType);
#define BSE_TYPE_BIQUAD_FILTER_NORM	    (BSE_TYPE_ID (BseBiquadFilterNorm))
extern GType BSE_TYPE_ID (BseBiquadFilterNorm);

/* --- bseenums.h --- */
#define BSE_TYPE_REGISTRATION_TYPE	    (BSE_TYPE_ID (BseRegistrationType))
extern GType BSE_TYPE_ID (BseRegistrationType);
#define BSE_TYPE_INTERPOL_TYPE	    (BSE_TYPE_ID (BseInterpolType))
extern GType BSE_TYPE_ID (BseInterpolType);
#define BSE_TYPE_LOOP_TYPE	    (BSE_TYPE_ID (BseLoopType))
extern GType BSE_TYPE_ID (BseLoopType);
#define BSE_TYPE_MAGIC_FLAGS	    (BSE_TYPE_ID (BseMagicFlags))
extern GType BSE_TYPE_ID (BseMagicFlags);
#define BSE_TYPE_ERROR_TYPE	    (BSE_TYPE_ID (BseErrorType))
extern GType BSE_TYPE_ID (BseErrorType);

/* --- bseglobals.h --- */
#define BSE_TYPE_TIME_RANGE_TYPE	    (BSE_TYPE_ID (BseTimeRangeType))
extern GType BSE_TYPE_ID (BseTimeRangeType);

/* --- bsemidievent.h --- */
#define BSE_TYPE_MIDI_EVENT_TYPE	    (BSE_TYPE_ID (BseMidiEventType))
extern GType BSE_TYPE_ID (BseMidiEventType);

/* --- bseproject.h --- */
#define BSE_TYPE_PROJECT_STATE	    (BSE_TYPE_ID (BseProjectState))
extern GType BSE_TYPE_ID (BseProjectState);

/* --- bsestandardosc.h --- */
#define BSE_TYPE_STANDARD_OSC_WAVE_TYPE	    (BSE_TYPE_ID (BseStandardOscWaveType))
extern GType BSE_TYPE_ID (BseStandardOscWaveType);

/* --- bsemididecoder.h --- */
#define BSE_TYPE_MIDI_DECODER_STATE	    (BSE_TYPE_ID (BseMidiDecoderState))
extern GType BSE_TYPE_ID (BseMidiDecoderState);




/*
 * Generated data (by mktypes.pl --externs)
 */

/* --- bsebus.c --- */
extern GType bse_type_builtin_id_BseBus;

/* --- bsebiquadfilter.c --- */
extern GType bse_type_builtin_id_BseBiquadFilter;

/* --- bseconstant.c --- */
extern GType bse_type_builtin_id_BseConstant;

/* --- bsecontainer.c --- */
extern GType bse_type_builtin_id_BseContainer;

/* --- bsecontextmerger.c --- */
extern GType bse_type_builtin_id_BseContextMerger;

/* --- bsedatapocket.c --- */
extern GType bse_type_builtin_id_BseDataPocket;

/* --- bseeditablesample.c --- */
extern GType bse_type_builtin_id_BseEditableSample;

/* --- bseitem.c --- */
extern GType bse_type_builtin_id_BseItem;

/* --- bsejanitor.c --- */
extern GType bse_type_builtin_id_BseJanitor;

/* --- bseladspa.cc --- */
extern GType bse_type_builtin_id_BseLadspaPlugin;

/* --- bsemidicontroller.c --- */
extern GType bse_type_builtin_id_BseMidiController;

/* --- bsemididevice.c --- */
extern GType bse_type_builtin_id_BseMidiDevice;

/* --- bsedevice.c --- */
extern GType bse_type_builtin_id_BseDevice;

/* --- bsemididevice-null.c --- */
extern GType bse_type_builtin_id_BseMidiDeviceNULL;

/* --- bsemididevice-oss.c --- */
extern GType bse_type_builtin_id_BseMidiDeviceOSS;

/* --- bsemidinotifier.c --- */
extern GType bse_type_builtin_id_BseMidiNotifier;

/* --- bsemidisynth.c --- */
extern GType bse_type_builtin_id_BseMidiSynth;

/* --- bseobject.c --- */
extern GType bse_type_builtin_id_BseObject;

/* --- bsepart.c --- */
extern GType bse_type_builtin_id_BsePart;

/* --- bsepcminput.c --- */
extern GType bse_type_builtin_id_BsePcmInput;

/* --- bsepcmoutput.c --- */
extern GType bse_type_builtin_id_BsePcmOutput;

/* --- bsepcmdevice.c --- */
extern GType bse_type_builtin_id_BsePcmDevice;

/* --- bsepcmdevice-oss.c --- */
extern GType bse_type_builtin_id_BsePcmDeviceOSS;

/* --- bsepcmdevice-null.c --- */
extern GType bse_type_builtin_id_BsePcmDeviceNull;

/* --- bseplugin.c --- */
extern GType bse_type_builtin_id_BsePlugin;

/* --- bseproject.c --- */
extern GType bse_type_builtin_id_BseProject;

/* --- bseserver.c --- */
extern GType bse_type_builtin_id_BseServer;

/* --- bsesnet.c --- */
extern GType bse_type_builtin_id_BseSNet;

/* --- bsesnooper.c --- */
extern GType bse_type_builtin_id_BseSnooper;

/* --- bsesong.c --- */
extern GType bse_type_builtin_id_BseSong;

/* --- bsesource.c --- */
extern GType bse_type_builtin_id_BseSource;

/* --- bsestandardosc.c --- */
extern GType bse_type_builtin_id_BseStandardOsc;

/* --- bsestorage.c --- */
extern GType bse_type_builtin_id_BseStorage;

/* --- bseinstrumentoutput.c --- */
extern GType bse_type_builtin_id_BseInstrumentOutput;

/* --- bsesubiport.c --- */
extern GType bse_type_builtin_id_BseSubIPort;

/* --- bseinstrumentinput.c --- */
extern GType bse_type_builtin_id_BseInstrumentInput;

/* --- bsesuboport.c --- */
extern GType bse_type_builtin_id_BseSubOPort;

/* --- bsesubsynth.c --- */
extern GType bse_type_builtin_id_BseSubSynth;

/* --- bsesuper.c --- */
extern GType bse_type_builtin_id_BseSuper;

/* --- bsetrack.c --- */
extern GType bse_type_builtin_id_BseTrack;

/* --- bsemidivoice.c --- */
extern GType bse_type_builtin_id_BseMidiVoiceInput;

/* --- bsemidivoice.c --- */
extern GType bse_type_builtin_id_BseMidiVoiceSwitch;

/* --- bsewave.c --- */
extern GType bse_type_builtin_id_BseWave;

/* --- bsewaveosc.c --- */
extern GType bse_type_builtin_id_BseWaveOsc;

/* --- bsecsynth.c --- */
extern GType bse_type_builtin_id_BseCSynth;

/* --- bsewaverepo.c --- */
extern GType bse_type_builtin_id_BseWaveRepo;

/* --- bseladspamodule.c --- */
extern GType bse_type_builtin_id_BseLadspaModule;

/* --- bsepcmwriter.c --- */
extern GType bse_type_builtin_id_BsePcmWriter;

/* --- bsemidiinput.c --- */
extern GType bse_type_builtin_id_BseMidiInput;

/*
 * Generated data ends here
 */

/*-------- begin ../sfi/sfidl generated code --------*/




/* enums */

typedef enum {
  BSE_MUSICAL_TUNING_12_TET = 1,
  BSE_MUSICAL_TUNING_7_TET = 2,
  BSE_MUSICAL_TUNING_5_TET = 3,
  BSE_MUSICAL_TUNING_DIATONIC_SCALE = 4,
  BSE_MUSICAL_TUNING_INDIAN_SCALE = 5,
  BSE_MUSICAL_TUNING_PYTHAGOREAN_TUNING = 6,
  BSE_MUSICAL_TUNING_PENTATONIC_5_LIMIT = 7,
  BSE_MUSICAL_TUNING_PENTATONIC_BLUES = 8,
  BSE_MUSICAL_TUNING_PENTATONIC_GOGO = 9,
  BSE_MUSICAL_TUNING_QUARTER_COMMA_MEANTONE = 10,
  BSE_MUSICAL_TUNING_SILBERMANN_SORGE = 11,
  BSE_MUSICAL_TUNING_WERCKMEISTER_3 = 12,
  BSE_MUSICAL_TUNING_WERCKMEISTER_4 = 13,
  BSE_MUSICAL_TUNING_WERCKMEISTER_5 = 14,
  BSE_MUSICAL_TUNING_WERCKMEISTER_6 = 15,
  BSE_MUSICAL_TUNING_KIRNBERGER_3 = 16,
  BSE_MUSICAL_TUNING_YOUNG = 17,
} BseMusicalTuningType;

typedef enum {
  BSE_MIDI_SIGNAL_PROGRAM = 1,
  BSE_MIDI_SIGNAL_PRESSURE = 2,
  BSE_MIDI_SIGNAL_PITCH_BEND = 3,
  BSE_MIDI_SIGNAL_VELOCITY = 4,
  BSE_MIDI_SIGNAL_FINE_TUNE = 5,
  BSE_MIDI_SIGNAL_CONTINUOUS_0 = 64,
  BSE_MIDI_SIGNAL_CONTINUOUS_1 = 65,
  BSE_MIDI_SIGNAL_CONTINUOUS_2 = 66,
  BSE_MIDI_SIGNAL_CONTINUOUS_3 = 67,
  BSE_MIDI_SIGNAL_CONTINUOUS_4 = 68,
  BSE_MIDI_SIGNAL_CONTINUOUS_5 = 69,
  BSE_MIDI_SIGNAL_CONTINUOUS_6 = 70,
  BSE_MIDI_SIGNAL_CONTINUOUS_7 = 71,
  BSE_MIDI_SIGNAL_CONTINUOUS_8 = 72,
  BSE_MIDI_SIGNAL_CONTINUOUS_9 = 73,
  BSE_MIDI_SIGNAL_CONTINUOUS_10 = 74,
  BSE_MIDI_SIGNAL_CONTINUOUS_11 = 75,
  BSE_MIDI_SIGNAL_CONTINUOUS_12 = 76,
  BSE_MIDI_SIGNAL_CONTINUOUS_13 = 77,
  BSE_MIDI_SIGNAL_CONTINUOUS_14 = 78,
  BSE_MIDI_SIGNAL_CONTINUOUS_15 = 79,
  BSE_MIDI_SIGNAL_CONTINUOUS_16 = 80,
  BSE_MIDI_SIGNAL_CONTINUOUS_17 = 81,
  BSE_MIDI_SIGNAL_CONTINUOUS_18 = 82,
  BSE_MIDI_SIGNAL_CONTINUOUS_19 = 83,
  BSE_MIDI_SIGNAL_CONTINUOUS_20 = 84,
  BSE_MIDI_SIGNAL_CONTINUOUS_21 = 85,
  BSE_MIDI_SIGNAL_CONTINUOUS_22 = 86,
  BSE_MIDI_SIGNAL_CONTINUOUS_23 = 87,
  BSE_MIDI_SIGNAL_CONTINUOUS_24 = 88,
  BSE_MIDI_SIGNAL_CONTINUOUS_25 = 89,
  BSE_MIDI_SIGNAL_CONTINUOUS_26 = 90,
  BSE_MIDI_SIGNAL_CONTINUOUS_27 = 91,
  BSE_MIDI_SIGNAL_CONTINUOUS_28 = 92,
  BSE_MIDI_SIGNAL_CONTINUOUS_29 = 93,
  BSE_MIDI_SIGNAL_CONTINUOUS_30 = 94,
  BSE_MIDI_SIGNAL_CONTINUOUS_31 = 95,
  BSE_MIDI_SIGNAL_CONSTANT_HIGH = 96,
  BSE_MIDI_SIGNAL_CONSTANT_CENTER = 97,
  BSE_MIDI_SIGNAL_CONSTANT_LOW = 98,
  BSE_MIDI_SIGNAL_CONSTANT_NEGATIVE_CENTER = 99,
  BSE_MIDI_SIGNAL_CONSTANT_NEGATIVE_HIGH = 100,
  BSE_MIDI_SIGNAL_PARAMETER = 101,
  BSE_MIDI_SIGNAL_NON_PARAMETER = 102,
  BSE_MIDI_SIGNAL_CONTROL_0 = 128,
  BSE_MIDI_SIGNAL_CONTROL_1 = 129,
  BSE_MIDI_SIGNAL_CONTROL_2 = 130,
  BSE_MIDI_SIGNAL_CONTROL_3 = 131,
  BSE_MIDI_SIGNAL_CONTROL_4 = 132,
  BSE_MIDI_SIGNAL_CONTROL_5 = 133,
  BSE_MIDI_SIGNAL_CONTROL_6 = 134,
  BSE_MIDI_SIGNAL_CONTROL_7 = 135,
  BSE_MIDI_SIGNAL_CONTROL_8 = 136,
  BSE_MIDI_SIGNAL_CONTROL_9 = 137,
  BSE_MIDI_SIGNAL_CONTROL_10 = 138,
  BSE_MIDI_SIGNAL_CONTROL_11 = 139,
  BSE_MIDI_SIGNAL_CONTROL_12 = 140,
  BSE_MIDI_SIGNAL_CONTROL_13 = 141,
  BSE_MIDI_SIGNAL_CONTROL_14 = 142,
  BSE_MIDI_SIGNAL_CONTROL_15 = 143,
  BSE_MIDI_SIGNAL_CONTROL_16 = 144,
  BSE_MIDI_SIGNAL_CONTROL_17 = 145,
  BSE_MIDI_SIGNAL_CONTROL_18 = 146,
  BSE_MIDI_SIGNAL_CONTROL_19 = 147,
  BSE_MIDI_SIGNAL_CONTROL_20 = 148,
  BSE_MIDI_SIGNAL_CONTROL_21 = 149,
  BSE_MIDI_SIGNAL_CONTROL_22 = 150,
  BSE_MIDI_SIGNAL_CONTROL_23 = 151,
  BSE_MIDI_SIGNAL_CONTROL_24 = 152,
  BSE_MIDI_SIGNAL_CONTROL_25 = 153,
  BSE_MIDI_SIGNAL_CONTROL_26 = 154,
  BSE_MIDI_SIGNAL_CONTROL_27 = 155,
  BSE_MIDI_SIGNAL_CONTROL_28 = 156,
  BSE_MIDI_SIGNAL_CONTROL_29 = 157,
  BSE_MIDI_SIGNAL_CONTROL_30 = 158,
  BSE_MIDI_SIGNAL_CONTROL_31 = 159,
  BSE_MIDI_SIGNAL_CONTROL_32 = 160,
  BSE_MIDI_SIGNAL_CONTROL_33 = 161,
  BSE_MIDI_SIGNAL_CONTROL_34 = 162,
  BSE_MIDI_SIGNAL_CONTROL_35 = 163,
  BSE_MIDI_SIGNAL_CONTROL_36 = 164,
  BSE_MIDI_SIGNAL_CONTROL_37 = 165,
  BSE_MIDI_SIGNAL_CONTROL_38 = 166,
  BSE_MIDI_SIGNAL_CONTROL_39 = 167,
  BSE_MIDI_SIGNAL_CONTROL_40 = 168,
  BSE_MIDI_SIGNAL_CONTROL_41 = 169,
  BSE_MIDI_SIGNAL_CONTROL_42 = 170,
  BSE_MIDI_SIGNAL_CONTROL_43 = 171,
  BSE_MIDI_SIGNAL_CONTROL_44 = 172,
  BSE_MIDI_SIGNAL_CONTROL_45 = 173,
  BSE_MIDI_SIGNAL_CONTROL_46 = 174,
  BSE_MIDI_SIGNAL_CONTROL_47 = 175,
  BSE_MIDI_SIGNAL_CONTROL_48 = 176,
  BSE_MIDI_SIGNAL_CONTROL_49 = 177,
  BSE_MIDI_SIGNAL_CONTROL_50 = 178,
  BSE_MIDI_SIGNAL_CONTROL_51 = 179,
  BSE_MIDI_SIGNAL_CONTROL_52 = 180,
  BSE_MIDI_SIGNAL_CONTROL_53 = 181,
  BSE_MIDI_SIGNAL_CONTROL_54 = 182,
  BSE_MIDI_SIGNAL_CONTROL_55 = 183,
  BSE_MIDI_SIGNAL_CONTROL_56 = 184,
  BSE_MIDI_SIGNAL_CONTROL_57 = 185,
  BSE_MIDI_SIGNAL_CONTROL_58 = 186,
  BSE_MIDI_SIGNAL_CONTROL_59 = 187,
  BSE_MIDI_SIGNAL_CONTROL_60 = 188,
  BSE_MIDI_SIGNAL_CONTROL_61 = 189,
  BSE_MIDI_SIGNAL_CONTROL_62 = 190,
  BSE_MIDI_SIGNAL_CONTROL_63 = 191,
  BSE_MIDI_SIGNAL_CONTROL_64 = 192,
  BSE_MIDI_SIGNAL_CONTROL_65 = 193,
  BSE_MIDI_SIGNAL_CONTROL_66 = 194,
  BSE_MIDI_SIGNAL_CONTROL_67 = 195,
  BSE_MIDI_SIGNAL_CONTROL_68 = 196,
  BSE_MIDI_SIGNAL_CONTROL_69 = 197,
  BSE_MIDI_SIGNAL_CONTROL_70 = 198,
  BSE_MIDI_SIGNAL_CONTROL_71 = 199,
  BSE_MIDI_SIGNAL_CONTROL_72 = 200,
  BSE_MIDI_SIGNAL_CONTROL_73 = 201,
  BSE_MIDI_SIGNAL_CONTROL_74 = 202,
  BSE_MIDI_SIGNAL_CONTROL_75 = 203,
  BSE_MIDI_SIGNAL_CONTROL_76 = 204,
  BSE_MIDI_SIGNAL_CONTROL_77 = 205,
  BSE_MIDI_SIGNAL_CONTROL_78 = 206,
  BSE_MIDI_SIGNAL_CONTROL_79 = 207,
  BSE_MIDI_SIGNAL_CONTROL_80 = 208,
  BSE_MIDI_SIGNAL_CONTROL_81 = 209,
  BSE_MIDI_SIGNAL_CONTROL_82 = 210,
  BSE_MIDI_SIGNAL_CONTROL_83 = 211,
  BSE_MIDI_SIGNAL_CONTROL_84 = 212,
  BSE_MIDI_SIGNAL_CONTROL_85 = 213,
  BSE_MIDI_SIGNAL_CONTROL_86 = 214,
  BSE_MIDI_SIGNAL_CONTROL_87 = 215,
  BSE_MIDI_SIGNAL_CONTROL_88 = 216,
  BSE_MIDI_SIGNAL_CONTROL_89 = 217,
  BSE_MIDI_SIGNAL_CONTROL_90 = 218,
  BSE_MIDI_SIGNAL_CONTROL_91 = 219,
  BSE_MIDI_SIGNAL_CONTROL_92 = 220,
  BSE_MIDI_SIGNAL_CONTROL_93 = 221,
  BSE_MIDI_SIGNAL_CONTROL_94 = 222,
  BSE_MIDI_SIGNAL_CONTROL_95 = 223,
  BSE_MIDI_SIGNAL_CONTROL_96 = 224,
  BSE_MIDI_SIGNAL_CONTROL_97 = 225,
  BSE_MIDI_SIGNAL_CONTROL_98 = 226,
  BSE_MIDI_SIGNAL_CONTROL_99 = 227,
  BSE_MIDI_SIGNAL_CONTROL_100 = 228,
  BSE_MIDI_SIGNAL_CONTROL_101 = 229,
  BSE_MIDI_SIGNAL_CONTROL_102 = 230,
  BSE_MIDI_SIGNAL_CONTROL_103 = 231,
  BSE_MIDI_SIGNAL_CONTROL_104 = 232,
  BSE_MIDI_SIGNAL_CONTROL_105 = 233,
  BSE_MIDI_SIGNAL_CONTROL_106 = 234,
  BSE_MIDI_SIGNAL_CONTROL_107 = 235,
  BSE_MIDI_SIGNAL_CONTROL_108 = 236,
  BSE_MIDI_SIGNAL_CONTROL_109 = 237,
  BSE_MIDI_SIGNAL_CONTROL_110 = 238,
  BSE_MIDI_SIGNAL_CONTROL_111 = 239,
  BSE_MIDI_SIGNAL_CONTROL_112 = 240,
  BSE_MIDI_SIGNAL_CONTROL_113 = 241,
  BSE_MIDI_SIGNAL_CONTROL_114 = 242,
  BSE_MIDI_SIGNAL_CONTROL_115 = 243,
  BSE_MIDI_SIGNAL_CONTROL_116 = 244,
  BSE_MIDI_SIGNAL_CONTROL_117 = 245,
  BSE_MIDI_SIGNAL_CONTROL_118 = 246,
  BSE_MIDI_SIGNAL_CONTROL_119 = 247,
  BSE_MIDI_SIGNAL_CONTROL_120 = 248,
  BSE_MIDI_SIGNAL_CONTROL_121 = 249,
  BSE_MIDI_SIGNAL_CONTROL_122 = 250,
  BSE_MIDI_SIGNAL_CONTROL_123 = 251,
  BSE_MIDI_SIGNAL_CONTROL_124 = 252,
  BSE_MIDI_SIGNAL_CONTROL_125 = 253,
  BSE_MIDI_SIGNAL_CONTROL_126 = 254,
  BSE_MIDI_SIGNAL_CONTROL_127 = 255,
} BseMidiSignalType;

typedef enum {
  BSE_MIDI_CONTROL_NONE = 0,
  BSE_MIDI_CONTROL_CONTINUOUS_0 = 64,
  BSE_MIDI_CONTROL_CONTINUOUS_1 = 65,
  BSE_MIDI_CONTROL_CONTINUOUS_2 = 66,
  BSE_MIDI_CONTROL_CONTINUOUS_3 = 67,
  BSE_MIDI_CONTROL_CONTINUOUS_4 = 68,
  BSE_MIDI_CONTROL_CONTINUOUS_5 = 69,
  BSE_MIDI_CONTROL_CONTINUOUS_6 = 70,
  BSE_MIDI_CONTROL_CONTINUOUS_7 = 71,
  BSE_MIDI_CONTROL_CONTINUOUS_8 = 72,
  BSE_MIDI_CONTROL_CONTINUOUS_9 = 73,
  BSE_MIDI_CONTROL_CONTINUOUS_10 = 74,
  BSE_MIDI_CONTROL_CONTINUOUS_11 = 75,
  BSE_MIDI_CONTROL_CONTINUOUS_12 = 76,
  BSE_MIDI_CONTROL_CONTINUOUS_13 = 77,
  BSE_MIDI_CONTROL_CONTINUOUS_14 = 78,
  BSE_MIDI_CONTROL_CONTINUOUS_15 = 79,
  BSE_MIDI_CONTROL_CONTINUOUS_16 = 80,
  BSE_MIDI_CONTROL_CONTINUOUS_17 = 81,
  BSE_MIDI_CONTROL_CONTINUOUS_18 = 82,
  BSE_MIDI_CONTROL_CONTINUOUS_19 = 83,
  BSE_MIDI_CONTROL_CONTINUOUS_20 = 84,
  BSE_MIDI_CONTROL_CONTINUOUS_21 = 85,
  BSE_MIDI_CONTROL_CONTINUOUS_22 = 86,
  BSE_MIDI_CONTROL_CONTINUOUS_23 = 87,
  BSE_MIDI_CONTROL_CONTINUOUS_24 = 88,
  BSE_MIDI_CONTROL_CONTINUOUS_25 = 89,
  BSE_MIDI_CONTROL_CONTINUOUS_26 = 90,
  BSE_MIDI_CONTROL_CONTINUOUS_27 = 91,
  BSE_MIDI_CONTROL_CONTINUOUS_28 = 92,
  BSE_MIDI_CONTROL_CONTINUOUS_29 = 93,
  BSE_MIDI_CONTROL_CONTINUOUS_30 = 94,
  BSE_MIDI_CONTROL_CONTINUOUS_31 = 95,
  BSE_MIDI_CONTROL_0 = 128,
  BSE_MIDI_CONTROL_1 = 129,
  BSE_MIDI_CONTROL_2 = 130,
  BSE_MIDI_CONTROL_3 = 131,
  BSE_MIDI_CONTROL_4 = 132,
  BSE_MIDI_CONTROL_5 = 133,
  BSE_MIDI_CONTROL_6 = 134,
  BSE_MIDI_CONTROL_7 = 135,
  BSE_MIDI_CONTROL_8 = 136,
  BSE_MIDI_CONTROL_9 = 137,
  BSE_MIDI_CONTROL_10 = 138,
  BSE_MIDI_CONTROL_11 = 139,
  BSE_MIDI_CONTROL_12 = 140,
  BSE_MIDI_CONTROL_13 = 141,
  BSE_MIDI_CONTROL_14 = 142,
  BSE_MIDI_CONTROL_15 = 143,
  BSE_MIDI_CONTROL_16 = 144,
  BSE_MIDI_CONTROL_17 = 145,
  BSE_MIDI_CONTROL_18 = 146,
  BSE_MIDI_CONTROL_19 = 147,
  BSE_MIDI_CONTROL_20 = 148,
  BSE_MIDI_CONTROL_21 = 149,
  BSE_MIDI_CONTROL_22 = 150,
  BSE_MIDI_CONTROL_23 = 151,
  BSE_MIDI_CONTROL_24 = 152,
  BSE_MIDI_CONTROL_25 = 153,
  BSE_MIDI_CONTROL_26 = 154,
  BSE_MIDI_CONTROL_27 = 155,
  BSE_MIDI_CONTROL_28 = 156,
  BSE_MIDI_CONTROL_29 = 157,
  BSE_MIDI_CONTROL_30 = 158,
  BSE_MIDI_CONTROL_31 = 159,
  BSE_MIDI_CONTROL_32 = 160,
  BSE_MIDI_CONTROL_33 = 161,
  BSE_MIDI_CONTROL_34 = 162,
  BSE_MIDI_CONTROL_35 = 163,
  BSE_MIDI_CONTROL_36 = 164,
  BSE_MIDI_CONTROL_37 = 165,
  BSE_MIDI_CONTROL_38 = 166,
  BSE_MIDI_CONTROL_39 = 167,
  BSE_MIDI_CONTROL_40 = 168,
  BSE_MIDI_CONTROL_41 = 169,
  BSE_MIDI_CONTROL_42 = 170,
  BSE_MIDI_CONTROL_43 = 171,
  BSE_MIDI_CONTROL_44 = 172,
  BSE_MIDI_CONTROL_45 = 173,
  BSE_MIDI_CONTROL_46 = 174,
  BSE_MIDI_CONTROL_47 = 175,
  BSE_MIDI_CONTROL_48 = 176,
  BSE_MIDI_CONTROL_49 = 177,
  BSE_MIDI_CONTROL_50 = 178,
  BSE_MIDI_CONTROL_51 = 179,
  BSE_MIDI_CONTROL_52 = 180,
  BSE_MIDI_CONTROL_53 = 181,
  BSE_MIDI_CONTROL_54 = 182,
  BSE_MIDI_CONTROL_55 = 183,
  BSE_MIDI_CONTROL_56 = 184,
  BSE_MIDI_CONTROL_57 = 185,
  BSE_MIDI_CONTROL_58 = 186,
  BSE_MIDI_CONTROL_59 = 187,
  BSE_MIDI_CONTROL_60 = 188,
  BSE_MIDI_CONTROL_61 = 189,
  BSE_MIDI_CONTROL_62 = 190,
  BSE_MIDI_CONTROL_63 = 191,
  BSE_MIDI_CONTROL_64 = 192,
  BSE_MIDI_CONTROL_65 = 193,
  BSE_MIDI_CONTROL_66 = 194,
  BSE_MIDI_CONTROL_67 = 195,
  BSE_MIDI_CONTROL_68 = 196,
  BSE_MIDI_CONTROL_69 = 197,
  BSE_MIDI_CONTROL_70 = 198,
  BSE_MIDI_CONTROL_71 = 199,
  BSE_MIDI_CONTROL_72 = 200,
  BSE_MIDI_CONTROL_73 = 201,
  BSE_MIDI_CONTROL_74 = 202,
  BSE_MIDI_CONTROL_75 = 203,
  BSE_MIDI_CONTROL_76 = 204,
  BSE_MIDI_CONTROL_77 = 205,
  BSE_MIDI_CONTROL_78 = 206,
  BSE_MIDI_CONTROL_79 = 207,
  BSE_MIDI_CONTROL_80 = 208,
  BSE_MIDI_CONTROL_81 = 209,
  BSE_MIDI_CONTROL_82 = 210,
  BSE_MIDI_CONTROL_83 = 211,
  BSE_MIDI_CONTROL_84 = 212,
  BSE_MIDI_CONTROL_85 = 213,
  BSE_MIDI_CONTROL_86 = 214,
  BSE_MIDI_CONTROL_87 = 215,
  BSE_MIDI_CONTROL_88 = 216,
  BSE_MIDI_CONTROL_89 = 217,
  BSE_MIDI_CONTROL_90 = 218,
  BSE_MIDI_CONTROL_91 = 219,
  BSE_MIDI_CONTROL_92 = 220,
  BSE_MIDI_CONTROL_93 = 221,
  BSE_MIDI_CONTROL_94 = 222,
  BSE_MIDI_CONTROL_95 = 223,
  BSE_MIDI_CONTROL_96 = 224,
  BSE_MIDI_CONTROL_97 = 225,
  BSE_MIDI_CONTROL_98 = 226,
  BSE_MIDI_CONTROL_99 = 227,
  BSE_MIDI_CONTROL_100 = 228,
  BSE_MIDI_CONTROL_101 = 229,
  BSE_MIDI_CONTROL_102 = 230,
  BSE_MIDI_CONTROL_103 = 231,
  BSE_MIDI_CONTROL_104 = 232,
  BSE_MIDI_CONTROL_105 = 233,
  BSE_MIDI_CONTROL_106 = 234,
  BSE_MIDI_CONTROL_107 = 235,
  BSE_MIDI_CONTROL_108 = 236,
  BSE_MIDI_CONTROL_109 = 237,
  BSE_MIDI_CONTROL_110 = 238,
  BSE_MIDI_CONTROL_111 = 239,
  BSE_MIDI_CONTROL_112 = 240,
  BSE_MIDI_CONTROL_113 = 241,
  BSE_MIDI_CONTROL_114 = 242,
  BSE_MIDI_CONTROL_115 = 243,
  BSE_MIDI_CONTROL_116 = 244,
  BSE_MIDI_CONTROL_117 = 245,
  BSE_MIDI_CONTROL_118 = 246,
  BSE_MIDI_CONTROL_119 = 247,
  BSE_MIDI_CONTROL_120 = 248,
  BSE_MIDI_CONTROL_121 = 249,
  BSE_MIDI_CONTROL_122 = 250,
  BSE_MIDI_CONTROL_123 = 251,
  BSE_MIDI_CONTROL_124 = 252,
  BSE_MIDI_CONTROL_125 = 253,
  BSE_MIDI_CONTROL_126 = 254,
  BSE_MIDI_CONTROL_127 = 255,
} BseMidiControlType;

typedef enum {
  BSE_MIDI_EVENT_NONE = 0,
  BSE_MIDI_EVENT_NOTE_OFF = 1,
  BSE_MIDI_EVENT_NOTE_ON = 2,
  BSE_MIDI_EVENT_KEY_PRESSURE = 3,
  BSE_MIDI_EVENT_CONTROL_CHANGE = 4,
  BSE_MIDI_EVENT_PROGRAM_CHANGE = 5,
  BSE_MIDI_EVENT_CHANNEL_PRESSURE = 6,
  BSE_MIDI_EVENT_PITCH_BEND = 7,
  BSE_MIDI_EVENT_SYS_EX = 8,
  BSE_MIDI_EVENT_SONG_POINTER = 9,
  BSE_MIDI_EVENT_SONG_SELECT = 10,
  BSE_MIDI_EVENT_TUNE = 11,
  BSE_MIDI_EVENT_TIMING_CLOCK = 12,
  BSE_MIDI_EVENT_SONG_START = 13,
  BSE_MIDI_EVENT_SONG_CONTINUE = 14,
  BSE_MIDI_EVENT_SONG_STOP = 15,
  BSE_MIDI_EVENT_ACTIVE_SENSING = 16,
  BSE_MIDI_EVENT_SYSTEM_RESET = 17,
} BseMidiChannelEventType;

typedef enum {
  BSE_MSG_NONE = 0,
  BSE_MSG_ALWAYS = 1,
  BSE_MSG_ERROR = 2,
  BSE_MSG_WARNING = 3,
  BSE_MSG_SCRIPT = 4,
  BSE_MSG_INFO = 5,
  BSE_MSG_DIAG = 6,
  BSE_MSG_DEBUG = 7,
} BseMsgType;

typedef enum {
  BSE_THREAD_STATE_UNKNOWN = 0,
  BSE_THREAD_STATE_RUNNING = 1,
  BSE_THREAD_STATE_SLEEPING = 2,
  BSE_THREAD_STATE_DISKWAIT = 3,
  BSE_THREAD_STATE_TRACED = 4,
  BSE_THREAD_STATE_PAGING = 5,
  BSE_THREAD_STATE_ZOMBIE = 6,
  BSE_THREAD_STATE_DEAD = 7,
} BseThreadState;


/* record typedefs */
typedef struct _BseMidiChannelEvent BseMidiChannelEvent;
typedef struct _BsePropertyCandidates BsePropertyCandidates;
typedef struct _BsePartNote BsePartNote;
typedef struct _BsePartControl BsePartControl;
typedef struct _BseNoteDescription BseNoteDescription;
typedef struct _BseNoteSequence BseNoteSequence;
typedef struct _BseIcon BseIcon;
typedef struct _BseCategory BseCategory;
typedef struct _BseDot BseDot;
typedef struct _BsePartLink BsePartLink;
typedef struct _BseTrackPart BseTrackPart;
typedef struct _BseSongTiming BseSongTiming;
typedef struct _BseSampleFileInfo BseSampleFileInfo;
typedef struct _BseMessage BseMessage;
typedef struct _BseThreadInfo BseThreadInfo;
typedef struct _BseThreadTotals BseThreadTotals;
typedef struct _BseGConfig BseGConfig;


/* sequence typedefs */
typedef struct _BseIntSeq BseIntSeq;
typedef struct _BseTypeSeq BseTypeSeq;
typedef struct _BseStringSeq BseStringSeq;
typedef struct _BseNoteSeq BseNoteSeq;
typedef struct _BseItemSeq BseItemSeq;
typedef struct _BsePartNoteSeq BsePartNoteSeq;
typedef struct _BsePartControlSeq BsePartControlSeq;
typedef struct _BseCategorySeq BseCategorySeq;
typedef struct _BseDotSeq BseDotSeq;
typedef struct _BsePartLinkSeq BsePartLinkSeq;
typedef struct _BseTrackPartSeq BseTrackPartSeq;
typedef struct _BseThreadInfoSeq BseThreadInfoSeq;


/* sequences */
struct _BseIntSeq {
  guint n_ints;
  SfiInt* ints;
};
struct _BseTypeSeq {
  guint n_types;
  gchar** types;
};
struct _BseStringSeq {
  guint n_strings;
  gchar** strings;
};
struct _BseNoteSeq {
  guint n_notes;
  SfiInt* notes;
};
struct _BseItemSeq {
  guint n_items;
  BseItem** items;
};
struct _BsePartNoteSeq {
  guint n_pnotes;
  BsePartNote** pnotes;
};
struct _BsePartControlSeq {
  guint n_pcontrols;
  BsePartControl** pcontrols;
};
struct _BseCategorySeq {
  guint n_cats;
  BseCategory** cats;
};
struct _BseDotSeq {
  guint n_dots;
  BseDot** dots;
};
struct _BsePartLinkSeq {
  guint n_plinks;
  BsePartLink** plinks;
};
struct _BseTrackPartSeq {
  guint n_tparts;
  BseTrackPart** tparts;
};
struct _BseThreadInfoSeq {
  guint n_thread_infos;
  BseThreadInfo** thread_infos;
};


/* records */
struct _BseMidiChannelEvent {
  BseMidiChannelEventType event_type;
  SfiInt channel;
  SfiNum tick_stamp;
  SfiReal frequency;
  SfiReal velocity;
  SfiInt control;
  SfiReal value;
  SfiInt program;
  SfiReal intensity;
  SfiReal pitch_bend;
  SfiInt song_pointer;
  SfiInt song_number;
};
struct _BsePropertyCandidates {
  gchar* label;
  gchar* tooltip;
  BseItemSeq* items;
  BseTypeSeq* partitions;
};
struct _BsePartNote {
  SfiInt id;
  SfiInt channel;
  SfiInt tick;
  SfiInt duration;
  SfiInt note;
  SfiInt fine_tune;
  SfiReal velocity;
  SfiBool selected;
};
struct _BsePartControl {
  SfiInt id;
  SfiInt tick;
  BseMidiSignalType control_type;
  SfiReal value;
  SfiBool selected;
};
struct _BseNoteDescription {
  BseMusicalTuningType musical_tuning;
  SfiInt note;
  SfiInt octave;
  SfiReal freq;
  SfiInt fine_tune;
  SfiInt semitone;
  SfiBool upshift;
  SfiInt letter;
  gchar* name;
  SfiInt max_fine_tune;
  SfiInt kammer_note;
};
struct _BseNoteSequence {
  SfiInt offset;
  BseNoteSeq* notes;
};
struct _BseIcon {
  SfiInt bytes_per_pixel;
  SfiInt width;
  SfiInt height;
  SfiBBlock* pixels;
};
struct _BseCategory {
  SfiInt category_id;
  gchar* category;
  SfiInt mindex;
  SfiInt lindex;
  gchar* type;
  BseIcon* icon;
};
struct _BseDot {
  SfiReal x;
  SfiReal y;
};
struct _BsePartLink {
  BseTrack* track;
  SfiInt tick;
  BsePart* part;
  SfiInt duration;
};
struct _BseTrackPart {
  SfiInt tick;
  BsePart* part;
  SfiInt duration;
};
struct _BseSongTiming {
  SfiInt tick;
  SfiReal bpm;
  SfiInt numerator;
  SfiInt denominator;
  SfiInt tpqn;
  SfiInt tpt;
  SfiReal stamp_ticks;
};
struct _BseSampleFileInfo {
  gchar* file;
  SfiInt size;
  SfiNum mtime;
  gchar* loader;
  BseStringSeq* waves;
  SfiInt error;
};
struct _BseMessage {
  gchar* log_domain;
  BseMsgType type;
  gchar* ident;
  gchar* label;
  gchar* title;
  gchar* primary;
  gchar* secondary;
  gchar* details;
  gchar* config_check;
  BseJanitor* janitor;
  gchar* process;
  SfiInt pid;
};
struct _BseThreadInfo {
  gchar* name;
  BseThreadState state;
  SfiInt thread_id;
  SfiInt priority;
  SfiInt processor;
  SfiInt utime;
  SfiInt stime;
  SfiInt cutime;
  SfiInt cstime;
};
struct _BseThreadTotals {
  BseThreadInfo* main;
  BseThreadInfo* sequencer;
  BseThreadInfoSeq* synthesis;
};
struct _BseGConfig {
  SfiInt synth_latency;
  SfiInt synth_mixing_freq;
  SfiInt synth_control_freq;
  SfiBool invert_sustain;
  gchar* author_default;
  gchar* license_default;
  gchar* sample_path;
  gchar* effect_path;
  gchar* instrument_path;
  gchar* script_path;
  gchar* plugin_path;
  gchar* ladspa_path;
};


/* record functions */
SfiRecFields bse_midi_channel_event_get_fields (void);
BseMidiChannelEvent* bse_midi_channel_event_new (void);
BseMidiChannelEvent* bse_midi_channel_event_copy_shallow (BseMidiChannelEvent* rec);
BseMidiChannelEvent* bse_midi_channel_event_from_rec (SfiRec *sfi_rec);
SfiRec *bse_midi_channel_event_to_rec (BseMidiChannelEvent* rec);
void bse_midi_channel_event_free (BseMidiChannelEvent* rec);

SfiRecFields bse_property_candidates_get_fields (void);
BsePropertyCandidates* bse_property_candidates_new (void);
BsePropertyCandidates* bse_property_candidates_copy_shallow (BsePropertyCandidates* rec);
BsePropertyCandidates* bse_property_candidates_from_rec (SfiRec *sfi_rec);
SfiRec *bse_property_candidates_to_rec (BsePropertyCandidates* rec);
void bse_property_candidates_free (BsePropertyCandidates* rec);

SfiRecFields bse_part_note_get_fields (void);
BsePartNote* bse_part_note_new (void);
BsePartNote* bse_part_note_copy_shallow (BsePartNote* rec);
BsePartNote* bse_part_note_from_rec (SfiRec *sfi_rec);
SfiRec *bse_part_note_to_rec (BsePartNote* rec);
void bse_part_note_free (BsePartNote* rec);

SfiRecFields bse_part_control_get_fields (void);
BsePartControl* bse_part_control_new (void);
BsePartControl* bse_part_control_copy_shallow (BsePartControl* rec);
BsePartControl* bse_part_control_from_rec (SfiRec *sfi_rec);
SfiRec *bse_part_control_to_rec (BsePartControl* rec);
void bse_part_control_free (BsePartControl* rec);

SfiRecFields bse_note_description_get_fields (void);
BseNoteDescription* bse_note_description_new (void);
BseNoteDescription* bse_note_description_copy_shallow (BseNoteDescription* rec);
BseNoteDescription* bse_note_description_from_rec (SfiRec *sfi_rec);
SfiRec *bse_note_description_to_rec (BseNoteDescription* rec);
void bse_note_description_free (BseNoteDescription* rec);

SfiRecFields bse_note_sequence_get_fields (void);
BseNoteSequence* bse_note_sequence_new (void);
BseNoteSequence* bse_note_sequence_copy_shallow (BseNoteSequence* rec);
BseNoteSequence* bse_note_sequence_from_rec (SfiRec *sfi_rec);
SfiRec *bse_note_sequence_to_rec (BseNoteSequence* rec);
void bse_note_sequence_free (BseNoteSequence* rec);

SfiRecFields bse_icon_get_fields (void);
BseIcon* bse_icon_new (void);
BseIcon* bse_icon_copy_shallow (BseIcon* rec);
BseIcon* bse_icon_from_rec (SfiRec *sfi_rec);
SfiRec *bse_icon_to_rec (BseIcon* rec);
void bse_icon_free (BseIcon* rec);

SfiRecFields bse_category_get_fields (void);
BseCategory* bse_category_new (void);
BseCategory* bse_category_copy_shallow (BseCategory* rec);
BseCategory* bse_category_from_rec (SfiRec *sfi_rec);
SfiRec *bse_category_to_rec (BseCategory* rec);
void bse_category_free (BseCategory* rec);

SfiRecFields bse_dot_get_fields (void);
BseDot* bse_dot_new (void);
BseDot* bse_dot_copy_shallow (BseDot* rec);
BseDot* bse_dot_from_rec (SfiRec *sfi_rec);
SfiRec *bse_dot_to_rec (BseDot* rec);
void bse_dot_free (BseDot* rec);

SfiRecFields bse_part_link_get_fields (void);
BsePartLink* bse_part_link_new (void);
BsePartLink* bse_part_link_copy_shallow (BsePartLink* rec);
BsePartLink* bse_part_link_from_rec (SfiRec *sfi_rec);
SfiRec *bse_part_link_to_rec (BsePartLink* rec);
void bse_part_link_free (BsePartLink* rec);

SfiRecFields bse_track_part_get_fields (void);
BseTrackPart* bse_track_part_new (void);
BseTrackPart* bse_track_part_copy_shallow (BseTrackPart* rec);
BseTrackPart* bse_track_part_from_rec (SfiRec *sfi_rec);
SfiRec *bse_track_part_to_rec (BseTrackPart* rec);
void bse_track_part_free (BseTrackPart* rec);

SfiRecFields bse_song_timing_get_fields (void);
BseSongTiming* bse_song_timing_new (void);
BseSongTiming* bse_song_timing_copy_shallow (BseSongTiming* rec);
BseSongTiming* bse_song_timing_from_rec (SfiRec *sfi_rec);
SfiRec *bse_song_timing_to_rec (BseSongTiming* rec);
void bse_song_timing_free (BseSongTiming* rec);

SfiRecFields bse_sample_file_info_get_fields (void);
BseSampleFileInfo* bse_sample_file_info_new (void);
BseSampleFileInfo* bse_sample_file_info_copy_shallow (BseSampleFileInfo* rec);
BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
void bse_sample_file_info_free (BseSampleFileInfo* rec);

SfiRecFields bse_message_get_fields (void);
BseMessage* bse_message_new (void);
BseMessage* bse_message_copy_shallow (BseMessage* rec);
BseMessage* bse_message_from_rec (SfiRec *sfi_rec);
SfiRec *bse_message_to_rec (BseMessage* rec);
void bse_message_free (BseMessage* rec);

SfiRecFields bse_thread_info_get_fields (void);
BseThreadInfo* bse_thread_info_new (void);
BseThreadInfo* bse_thread_info_copy_shallow (BseThreadInfo* rec);
BseThreadInfo* bse_thread_info_from_rec (SfiRec *sfi_rec);
SfiRec *bse_thread_info_to_rec (BseThreadInfo* rec);
void bse_thread_info_free (BseThreadInfo* rec);

SfiRecFields bse_thread_totals_get_fields (void);
BseThreadTotals* bse_thread_totals_new (void);
BseThreadTotals* bse_thread_totals_copy_shallow (BseThreadTotals* rec);
BseThreadTotals* bse_thread_totals_from_rec (SfiRec *sfi_rec);
SfiRec *bse_thread_totals_to_rec (BseThreadTotals* rec);
void bse_thread_totals_free (BseThreadTotals* rec);

SfiRecFields bse_gconfig_get_fields (void);
BseGConfig* bse_gconfig_new (void);
BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
BseGConfig* bse_gconfig_from_rec (SfiRec *sfi_rec);
SfiRec *bse_gconfig_to_rec (BseGConfig* rec);
void bse_gconfig_free (BseGConfig* rec);



/* sequence functions */
GParamSpec* bse_int_seq_get_element (void);
BseIntSeq* bse_int_seq_new (void);
void bse_int_seq_append (BseIntSeq* seq, SfiInt element);
BseIntSeq* bse_int_seq_copy_shallow (BseIntSeq* seq);
BseIntSeq* bse_int_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_int_seq_to_seq (BseIntSeq* seq);
void bse_int_seq_resize (BseIntSeq* seq, guint new_size);
void bse_int_seq_free (BseIntSeq* seq);

GParamSpec* bse_type_seq_get_element (void);
BseTypeSeq* bse_type_seq_new (void);
void bse_type_seq_append (BseTypeSeq* seq, const char* element);
BseTypeSeq* bse_type_seq_copy_shallow (BseTypeSeq* seq);
BseTypeSeq* bse_type_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_type_seq_to_seq (BseTypeSeq* seq);
void bse_type_seq_resize (BseTypeSeq* seq, guint new_size);
void bse_type_seq_free (BseTypeSeq* seq);

GParamSpec* bse_string_seq_get_element (void);
BseStringSeq* bse_string_seq_new (void);
void bse_string_seq_append (BseStringSeq* seq, const char* element);
BseStringSeq* bse_string_seq_copy_shallow (BseStringSeq* seq);
BseStringSeq* bse_string_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_string_seq_to_seq (BseStringSeq* seq);
void bse_string_seq_resize (BseStringSeq* seq, guint new_size);
void bse_string_seq_free (BseStringSeq* seq);

GParamSpec* bse_note_seq_get_element (void);
BseNoteSeq* bse_note_seq_new (void);
void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
BseNoteSeq* bse_note_seq_copy_shallow (BseNoteSeq* seq);
BseNoteSeq* bse_note_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_note_seq_to_seq (BseNoteSeq* seq);
void bse_note_seq_resize (BseNoteSeq* seq, guint new_size);
void bse_note_seq_free (BseNoteSeq* seq);

GParamSpec* bse_item_seq_get_element (void);
BseItemSeq* bse_item_seq_new (void);
void bse_item_seq_append (BseItemSeq* seq, BseItem* element);
BseItemSeq* bse_item_seq_copy_shallow (BseItemSeq* seq);
BseItemSeq* bse_item_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_item_seq_to_seq (BseItemSeq* seq);
void bse_item_seq_resize (BseItemSeq* seq, guint new_size);
void bse_item_seq_free (BseItemSeq* seq);

GParamSpec* bse_part_note_seq_get_element (void);
BsePartNoteSeq* bse_part_note_seq_new (void);
void bse_part_note_seq_append (BsePartNoteSeq* seq, BsePartNote* element);
BsePartNoteSeq* bse_part_note_seq_copy_shallow (BsePartNoteSeq* seq);
BsePartNoteSeq* bse_part_note_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_part_note_seq_to_seq (BsePartNoteSeq* seq);
void bse_part_note_seq_resize (BsePartNoteSeq* seq, guint new_size);
void bse_part_note_seq_free (BsePartNoteSeq* seq);

GParamSpec* bse_part_control_seq_get_element (void);
BsePartControlSeq* bse_part_control_seq_new (void);
void bse_part_control_seq_append (BsePartControlSeq* seq, BsePartControl* element);
BsePartControlSeq* bse_part_control_seq_copy_shallow (BsePartControlSeq* seq);
BsePartControlSeq* bse_part_control_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_part_control_seq_to_seq (BsePartControlSeq* seq);
void bse_part_control_seq_resize (BsePartControlSeq* seq, guint new_size);
void bse_part_control_seq_free (BsePartControlSeq* seq);

GParamSpec* bse_category_seq_get_element (void);
BseCategorySeq* bse_category_seq_new (void);
void bse_category_seq_append (BseCategorySeq* seq, BseCategory* element);
BseCategorySeq* bse_category_seq_copy_shallow (BseCategorySeq* seq);
BseCategorySeq* bse_category_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_category_seq_to_seq (BseCategorySeq* seq);
void bse_category_seq_resize (BseCategorySeq* seq, guint new_size);
void bse_category_seq_free (BseCategorySeq* seq);

GParamSpec* bse_dot_seq_get_element (void);
BseDotSeq* bse_dot_seq_new (void);
void bse_dot_seq_append (BseDotSeq* seq, BseDot* element);
BseDotSeq* bse_dot_seq_copy_shallow (BseDotSeq* seq);
BseDotSeq* bse_dot_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_dot_seq_to_seq (BseDotSeq* seq);
void bse_dot_seq_resize (BseDotSeq* seq, guint new_size);
void bse_dot_seq_free (BseDotSeq* seq);

GParamSpec* bse_part_link_seq_get_element (void);
BsePartLinkSeq* bse_part_link_seq_new (void);
void bse_part_link_seq_append (BsePartLinkSeq* seq, BsePartLink* element);
BsePartLinkSeq* bse_part_link_seq_copy_shallow (BsePartLinkSeq* seq);
BsePartLinkSeq* bse_part_link_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_part_link_seq_to_seq (BsePartLinkSeq* seq);
void bse_part_link_seq_resize (BsePartLinkSeq* seq, guint new_size);
void bse_part_link_seq_free (BsePartLinkSeq* seq);

GParamSpec* bse_track_part_seq_get_element (void);
BseTrackPartSeq* bse_track_part_seq_new (void);
void bse_track_part_seq_append (BseTrackPartSeq* seq, BseTrackPart* element);
BseTrackPartSeq* bse_track_part_seq_copy_shallow (BseTrackPartSeq* seq);
BseTrackPartSeq* bse_track_part_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_track_part_seq_to_seq (BseTrackPartSeq* seq);
void bse_track_part_seq_resize (BseTrackPartSeq* seq, guint new_size);
void bse_track_part_seq_free (BseTrackPartSeq* seq);

GParamSpec* bse_thread_info_seq_get_element (void);
BseThreadInfoSeq* bse_thread_info_seq_new (void);
void bse_thread_info_seq_append (BseThreadInfoSeq* seq, BseThreadInfo* element);
BseThreadInfoSeq* bse_thread_info_seq_copy_shallow (BseThreadInfoSeq* seq);
BseThreadInfoSeq* bse_thread_info_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_thread_info_seq_to_seq (BseThreadInfoSeq* seq);
void bse_thread_info_seq_resize (BseThreadInfoSeq* seq, guint new_size);
void bse_thread_info_seq_free (BseThreadInfoSeq* seq);



/* enum functions */
SfiChoiceValues bse_musical_tuning_type_get_values (void);
SfiChoiceValues bse_midi_signal_type_get_values (void);
SfiChoiceValues bse_midi_control_type_get_values (void);
SfiChoiceValues bse_midi_channel_event_type_get_values (void);
SfiChoiceValues bse_msg_type_get_values (void);
SfiChoiceValues bse_thread_state_get_values (void);


/* enum type ids */
extern GType bse__type_id__musical_tuning_type;
extern GType bse__type_id__midi_signal_type;
extern GType bse__type_id__midi_control_type;
extern GType bse__type_id__midi_channel_event_type;
extern GType bse__type_id__msg_type;
extern GType bse__type_id__thread_state;


/* record type ids */
extern GType bse__type_id__midi_channel_event;
extern GType bse__type_id__property_candidates;
extern GType bse__type_id__part_note;
extern GType bse__type_id__part_control;
extern GType bse__type_id__note_description;
extern GType bse__type_id__note_sequence;
extern GType bse__type_id__icon;
extern GType bse__type_id__category;
extern GType bse__type_id__dot;
extern GType bse__type_id__part_link;
extern GType bse__type_id__track_part;
extern GType bse__type_id__song_timing;
extern GType bse__type_id__sample_file_info;
extern GType bse__type_id__message;
extern GType bse__type_id__thread_info;
extern GType bse__type_id__thread_totals;
extern GType bse__type_id__gconfig;


/* sequence type ids */
extern GType bse__type_id__int_seq;
extern GType bse__type_id__type_seq;
extern GType bse__type_id__string_seq;
extern GType bse__type_id__note_seq;
extern GType bse__type_id__item_seq;
extern GType bse__type_id__part_note_seq;
extern GType bse__type_id__part_control_seq;
extern GType bse__type_id__category_seq;
extern GType bse__type_id__dot_seq;
extern GType bse__type_id__part_link_seq;
extern GType bse__type_id__track_part_seq;
extern GType bse__type_id__thread_info_seq;

#ifndef __cplusplus


/* enum type macros */
#define BSE_TYPE_MUSICAL_TUNING_TYPE		(bse__type_id__musical_tuning_type)
#define BSE_TYPE_MIDI_SIGNAL_TYPE		(bse__type_id__midi_signal_type)
#define BSE_TYPE_MIDI_CONTROL_TYPE		(bse__type_id__midi_control_type)
#define BSE_TYPE_MIDI_CHANNEL_EVENT_TYPE		(bse__type_id__midi_channel_event_type)
#define BSE_TYPE_MSG_TYPE		(bse__type_id__msg_type)
#define BSE_TYPE_THREAD_STATE		(bse__type_id__thread_state)


/* record type macros */
#define BSE_TYPE_MIDI_CHANNEL_EVENT		(bse__type_id__midi_channel_event)
#define BSE_TYPE_PROPERTY_CANDIDATES		(bse__type_id__property_candidates)
#define BSE_TYPE_PART_NOTE		(bse__type_id__part_note)
#define BSE_TYPE_PART_CONTROL		(bse__type_id__part_control)
#define BSE_TYPE_NOTE_DESCRIPTION		(bse__type_id__note_description)
#define BSE_TYPE_NOTE_SEQUENCE		(bse__type_id__note_sequence)
#define BSE_TYPE_ICON		(bse__type_id__icon)
#define BSE_TYPE_CATEGORY		(bse__type_id__category)
#define BSE_TYPE_DOT		(bse__type_id__dot)
#define BSE_TYPE_PART_LINK		(bse__type_id__part_link)
#define BSE_TYPE_TRACK_PART		(bse__type_id__track_part)
#define BSE_TYPE_SONG_TIMING		(bse__type_id__song_timing)
#define BSE_TYPE_SAMPLE_FILE_INFO		(bse__type_id__sample_file_info)
#define BSE_TYPE_MESSAGE		(bse__type_id__message)
#define BSE_TYPE_THREAD_INFO		(bse__type_id__thread_info)
#define BSE_TYPE_THREAD_TOTALS		(bse__type_id__thread_totals)
#define BSE_TYPE_GCONFIG		(bse__type_id__gconfig)


/* sequence type macros */
#define BSE_TYPE_INT_SEQ		(bse__type_id__int_seq)
#define BSE_TYPE_TYPE_SEQ		(bse__type_id__type_seq)
#define BSE_TYPE_STRING_SEQ		(bse__type_id__string_seq)
#define BSE_TYPE_NOTE_SEQ		(bse__type_id__note_seq)
#define BSE_TYPE_ITEM_SEQ		(bse__type_id__item_seq)
#define BSE_TYPE_PART_NOTE_SEQ		(bse__type_id__part_note_seq)
#define BSE_TYPE_PART_CONTROL_SEQ		(bse__type_id__part_control_seq)
#define BSE_TYPE_CATEGORY_SEQ		(bse__type_id__category_seq)
#define BSE_TYPE_DOT_SEQ		(bse__type_id__dot_seq)
#define BSE_TYPE_PART_LINK_SEQ		(bse__type_id__part_link_seq)
#define BSE_TYPE_TRACK_PART_SEQ		(bse__type_id__track_part_seq)
#define BSE_TYPE_THREAD_INFO_SEQ		(bse__type_id__thread_info_seq)

#endif

/*-------- end ../sfi/sfidl generated code --------*/


